@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2016-03-26'; # DATE
-our $VERSION = '0.57'; # VERSION
+our $DATE = '2016-03-29'; # DATE
+our $VERSION = '0.58'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -60,7 +60,7 @@ sub _process_module {
         # we import specifically when module is using Exporter::Rinci as its
         # exporter, because Exporter::Rinci works by filling @EXPORT* variables
         # during import().
-        if (sub_fullname(\&{"$package\::import"}) =~ /^Exporter::Rinci::/) {
+        if (sub_fullname($package->can("import")) =~ /^Exporter::Rinci::/) {
             $package->import;
         }
 
@@ -799,7 +799,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.57 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-03-26.
+This document describes version 0.58 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-03-29.
 
 =head1 SYNOPSIS
 
